@@ -25,12 +25,14 @@ MUST_BE_UNIQUE = "_must_be_unique"
 IGNORE_NONE_VALUES = "_ignore_none"
 MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS = 100000
 
+T = typing.TypeVar("T")
 
 
 class ImmutableMixin:
     """
     Helper for making a field immutable
     """
+
     _field_definition = None
     _instance = None
 
@@ -549,8 +551,6 @@ def convert_basic_types(v):
     return type_mapping.get(v, None)
 
 
-
-
 def get_typing_lib_info(v):
     from .fields import AnyOf
 
@@ -860,9 +860,9 @@ class Structure(UniqueMixin, metaclass=StructMeta):
         required = props.get(REQUIRED_FIELDS, field_names)
         additional_props = props.get(ADDITIONAL_PROPERTIES, True)
         return (
-                len(field_names) == 1
-                and required == field_names
-                and additional_props is False
+            len(field_names) == 1
+            and required == field_names
+            and additional_props is False
         )
 
     def __contains__(self, item):
@@ -880,7 +880,7 @@ class Structure(UniqueMixin, metaclass=StructMeta):
         field_names = list(field_by_name.keys())
         val = getattr(self, field_names[0], {})
 
-        if self._is_wrapper() and hasattr(val, '__iter__'):
+        if self._is_wrapper() and hasattr(val, "__iter__"):
             return iter(val)
         raise TypeError(
             "{} is not a wrapper of an iterable".format(self.__class__.__name__)
@@ -898,6 +898,39 @@ class Structure(UniqueMixin, metaclass=StructMeta):
         kw_args = {**field_value_by_name, **kw}
         return self.__class__(**kw_args)
 
+    def cast_to(self, cls: type(T)) -> T:
+        """
+        Shallow copy of the structure as the given class, which should be a subclass
+        or superclass of the structure's class
+        :param cls: the target class
+        :return: an instance of cls
+        """
+        if (
+            issubclass(cls, self.__class__)
+            or cls is self.__class__
+            or isinstance(self, cls)
+        ) and issubclass(cls, Structure):
+            that = (
+                deepcopy(self)
+                if (
+                    issubclass(cls, ImmutableStructure)
+                    or issubclass(self.__class__, ImmutableStructure)
+                )
+                else self
+            )
+
+            fields_names = cls.get_all_fields_by_name().keys()
+            field_value_by_name = dict(
+                [
+                    (f, getattr(that, f))
+                    for f in fields_names
+                    if getattr(that, f, None) is not None
+                ]
+            )
+            return cls(**field_value_by_name)
+
+        raise TypeError(f"cls must be subclass of {self.__class__.__name__}")
+
     @staticmethod
     def set_fail_fast(fast_fail: bool):
         Structure._fail_fast = fast_fail
